@@ -391,10 +391,12 @@ pub mod transactions {
         Assignment,
         #[serde(rename = "Forward Split")]
         ForwardSplit,
-        #[serde(rename = "Backwards Split")]
-        BackwardsSplit,
+        #[serde(rename = "Reverse Split")]
+        ReverseSplit,
         #[serde(rename = "Symbol Change")]
         SymbolChange,
+        #[serde(rename = "Stock Merger")]
+        StockMerger,
         #[serde(rename = "Sell to Open")]
         SellToOpen,
         #[serde(rename = "Buy to Open")]
@@ -544,12 +546,17 @@ pub mod transactions {
     impl From<csv::Transaction> for Item {
         fn from(csv: csv::Transaction) -> Self {
             let symbol = csv.symbol.clone().unwrap_or_default();
-            let instrument_type = serde_json::from_str(
-                csv.instrument_type
-                    .as_ref()
-                    .expect("Missing instrument type"),
-            )
-            .unwrap();
+            let instrument_type: Option<InstrumentType> =
+                csv.instrument_type.as_ref().map(|instrument_type_str| {
+                    serde_json::from_str(&format!("\"{}\"", instrument_type_str)).unwrap_or_else(
+                        |_| {
+                            panic!(
+                                "Failed to deserialize InstrumentType from '{}'",
+                                instrument_type_str
+                            )
+                        },
+                    )
+                });
             let underlying_symbol = csv.underlying_symbol().unwrap_or_default().to_string();
 
             let split_fees = Decimal(csv.fees.abs().0 / 3);
@@ -560,7 +567,7 @@ pub mod transactions {
                 Item::Trade(Trade {
                     id: 0,
                     symbol,
-                    instrument_type,
+                    instrument_type: instrument_type.expect("Missing instrument type"),
                     executed_at: csv.date,
                     action: csv.action.expect("Missing trade action").into(),
                     underlying_symbol,
@@ -587,8 +594,8 @@ pub mod transactions {
                     ReceiveDeliverTransactionSubType::Assignment
                 } else if description.contains("forward split") {
                     ReceiveDeliverTransactionSubType::ForwardSplit
-                } else if description.contains("backwards split") {
-                    ReceiveDeliverTransactionSubType::BackwardsSplit
+                } else if description.contains("reverse split") {
+                    ReceiveDeliverTransactionSubType::ReverseSplit
                 } else if description.contains("symbol change") {
                     ReceiveDeliverTransactionSubType::SymbolChange
                 } else if description.contains("sell to open") {
@@ -606,7 +613,7 @@ pub mod transactions {
                 Item::ReceiveDeliver(ReceiveDeliver {
                     id: 0,
                     symbol,
-                    instrument_type,
+                    instrument_type: instrument_type.expect("Missing instrument type"),
                     transaction_sub_type,
                     executed_at: csv.date,
                     action: csv.action.map(|action| action.into()),
